import React, { useEffect } from "react";
import {
    ActionType,
    FooterToolbar,
    PageContainer,
    ProDescriptions,
    ProDescriptionsItemProps,
    ProTable,
} from '@ant-design/pro-components';
import { Options, Meta2d } from "@meta2d/core";
import { flowPens } from "@meta2d/flow-diagram";
import { activityDiagram } from "@meta2d/activity-diagram";
import { classPens } from "@meta2d/class-diagram";
import { sequencePens, sequencePensbyCtx } from "@meta2d/sequence-diagram";
import { formPens } from "@meta2d/form-diagram";
import { Button, Divider, Drawer, message } from 'antd';
import styles from './index.less';
import _ from 'lodash';
const Topo: React.FC<unknown> = () => {
    useEffect(() => {
        window.meta2d = new Meta2d("meta2d", {
            grid: true,
            padding: 10,
            disableTranslate: true,
            disableScale: true,
            activeColor: '#ff3300',
            activeBackground: 'green',
        });
        meta2d.register(flowPens());
        meta2d.register(activityDiagram());
        meta2d.register(classPens());
        meta2d.register(sequencePens());
        meta2d.registerCanvasDraw(sequencePensbyCtx());
        meta2d.registerCanvasDraw(formPens());
        // const pen = {
        //     name: 'image',
        //     text: '',
        //     x: 100,
        //     y: 100,
        //     width: 40,
        //     height: 40,
        //     image: require('@/img/test.png')
        // };
        const pens = [];
        const yArr = [];
        for (let i = 0; i < 200; i++) {
            for (let j = 0; j < 25; j++) {
                const x = 10 + j * 58;  // x坐标每次增加60
                const y = 10 + i * 58;  // y坐标每次增加60
                yArr.push(y);
                const pen = {
                    id: 'wind_' + i.toString() + "_" + j.toString(),
                    name: 'rectangle',
                    text: '',
                    x,
                    y,
                    locked: 1,//禁止编辑 + 移动；可选中、高亮、触发事件等
                    radio: true,
                    hover: false,
                    width: 40,
                    height: 40,
                    image: require('@/img/test.png'),
                    lineWidth: 0
                };
                pens.push(pen);
            }
        };
        const maxHeight = _.max(yArr) + 100
        console.log('yArr', yArr, `maxHeight is:`, maxHeight)
        meta2d.addPens(pens);

        const fn = (event: any, data: any) => {
            console.log('event', event, `data is:`, data);
            if (event === 'mouseup' && data?.pen) {
                message.info(data?.pen?.id)
            } else if (event === 'click' && data?.pen) {
                const pen = data?.pen;
                meta2d.setValue({ id: pen?.id, lineWidth: 4 });
                meta2d.inactive();
            }
        };
        meta2d.on('*', fn);
        // meta2d.lock(1);
        setTimeout(() => {
            const oDomWidth = document.getElementById('J_meta_parent')?.offsetWidth;
            meta2d.resize(1600, maxHeight);
            const pen1 = meta2d.findOne('wind_4_0');
            const pen2 = meta2d.findOne('wind_0_0');

        }, 1000);

        // 打开文件     
        //const json = []
        // meta2d.open(json);
    }, []);
    return (
        <PageContainer
            header={{
                title: 'Topo测试',
            }}
        >
            <div className="main" id="J_meta_parent">
                <div className={styles.meta2D} id="meta2d"></div>
            </div>
        </PageContainer>)
}
export default Topo;
